@@ -8,6 +8,7 @@ mod mangadex_duration;
 mod order_direction;
 mod password;
 mod report_category;
+mod report_status;
 mod sort_order;
 mod static_data;
 mod tag;
@@ -26,6 +27,7 @@ pub use mangadex_duration::MangaDexDuration;
 pub use order_direction::OrderDirection;
 pub use password::Password;
 pub use report_category::ReportCategory;
+pub use report_status::ReportStatus;
 pub use sort_order::*;
 pub use static_data::content_rating::ContentRating;
 pub use static_data::custom_list_visibility::CustomListVisibility;
