@@ -36,6 +36,7 @@ sort_order! {
         Chapter,
         CreatedAt,
         PublishAt,
+        ReadableAt,
         UpdatedAt,
         Volume,
     }
@@ -76,10 +77,17 @@ sort_order! {
 sort_order! {
     MangaFeedSortOrder {
         Chapter,
-        Volume,
         CreatedAt,
-        UpdatedAt,
         PublishAt,
+        ReadableAt,
+        UpdatedAt,
+        Volume,
+    }
+}
+
+sort_order! {
+    ReportSortOrder {
+        CreatedAt,
     }
 }
 
