@@ -42,6 +42,7 @@ use derive_builder::Builder;
 use serde::Serialize;
 use uuid::Uuid;
 
+use crate::types::Language;
 use crate::v5::schema::CoverResponse;
 use crate::HttpClientRef;
 
@@ -66,6 +67,9 @@ pub struct EditCover<'a> {
     #[serde(skip_serializing_if = "Option::is_none")]
     #[builder(default)]
     pub description: Option<Option<&'a str>>,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    #[builder(default)]
+    pub locale: Option<Option<Language>>,
     /// >= 1
     pub version: u32,
 }
@@ -136,6 +140,7 @@ mod tests {
                     "volume": "1",
                     "fileName": "1.jpg",
                     "description": description,
+                    "locale": "en",
                     "version": 1,
                     "createdAt": datetime.to_string(),
                     "updatedAt": datetime.to_string(),
