@@ -75,7 +75,7 @@ mod tests {
     use wiremock::{Mock, MockServer, ResponseTemplate};
 
     use crate::error::Error;
-    use crate::types::MangaDexDateTime;
+    use crate::types::{Language, MangaDexDateTime};
     use crate::{HttpClient, MangaDexClient};
 
     #[tokio::test]
@@ -110,6 +110,7 @@ mod tests {
                     "volume": "1",
                     "fileName": "1.jpg",
                     "description": description,
+                    "locale": "en",
                     "version": 1,
                     "createdAt": datetime.to_string(),
                     "updatedAt": datetime.to_string(),
@@ -138,6 +139,7 @@ mod tests {
         assert_eq!(res.data.attributes.volume, Some("1".to_string()));
         assert_eq!(res.data.attributes.file_name, "1.jpg".to_string());
         assert_eq!(res.data.attributes.description, description);
+        assert_eq!(res.data.attributes.locale, Some(Language::English));
         assert_eq!(res.data.attributes.version, 1);
         assert_eq!(
             res.data.attributes.created_at.to_string(),
