@@ -6,7 +6,7 @@
 //! use uuid::Uuid;
 //!
 //! use mangadex_api::MangaDexClient;
-//! use mangadex_api::types::{Password, Username};;
+//! use mangadex_api::types::{Language, Password, Username};;
 //!
 //! # async fn run() -> anyhow::Result<()> {
 //! let client = MangaDexClient::default();
@@ -27,6 +27,7 @@
 //!     .upload()
 //!     .manga_id(&manga_id)
 //!     .file(file_bytes)
+//!     .locale(Language::English)
 //!     .build()?
 //!     .send()
 //!     .await?;
@@ -43,9 +44,9 @@ use reqwest::multipart::{Form, Part};
 use serde::Serialize;
 use uuid::Uuid;
 
+use crate::types::Language;
 use crate::v5::schema::CoverResponse;
-use crate::Endpoint;
-use crate::HttpClientRef;
+use crate::{Endpoint, HttpClientRef};
 
 /// Upload a new cover for a manga.
 ///
@@ -78,6 +79,7 @@ pub struct UploadCover<'a> {
     pub volume: Option<Cow<'a, str>>,
     #[builder(default)]
     pub description: Cow<'a, str>,
+    pub locale: Language,
 }
 
 // TODO: Come up with a way to generalize multipart form data for the `Endpoint` trait.
@@ -109,6 +111,8 @@ impl Endpoint for UploadCover<'_> {
 
         form = form.part("description", Part::text(self.description.to_string()));
 
+        form = form.part("locale", Part::text(self.locale.code2().to_string()));
+
         Some(form)
     }
 }
@@ -142,7 +146,7 @@ mod tests {
     use wiremock::matchers::{header, header_exists, method, path_regex};
     use wiremock::{Mock, MockServer, ResponseTemplate};
 
-    use crate::types::MangaDexDateTime;
+    use crate::types::{Language, MangaDexDateTime};
     use crate::v5::AuthTokens;
     use crate::{HttpClient, MangaDexClient};
 
@@ -184,6 +188,7 @@ mod tests {
                     "volume": "1",
                     "fileName": "1.jpg",
                     "description": description,
+                    "locale": "en",
                     "version": 1,
                     "createdAt": datetime.to_string(),
                     "updatedAt": datetime.to_string(),
@@ -207,6 +212,7 @@ mod tests {
             .cover()
             .manga_id(&manga_id)
             .file(file_bytes)
+            .locale(Language::English)
             .build()?
             .send()
             .await?;
