@@ -91,6 +91,8 @@ pub struct CreateManga<'a> {
     #[builder(default)]
     pub year: Option<Option<u16>>,
     pub content_rating: ContentRating,
+    #[builder(default)]
+    pub chapter_numbers_reset_on_new_volume: bool,
     #[serde(skip_serializing_if = "Option::is_none")]
     #[builder(default)]
     pub tags: Option<Vec<Tag>>,
@@ -188,6 +190,7 @@ mod tests {
                     "status": "ongoing",
                     "year": null,
                     "contentRating": "safe",
+                    "chapterNumbersResetOnNewVolume": true,
                     "tags": [
                         {
                             "id": tag_id,
@@ -261,6 +264,7 @@ mod tests {
             res.data.attributes.content_rating.unwrap(),
             ContentRating::Safe
         );
+        assert!(res.data.attributes.chapter_numbers_reset_on_new_volume);
         assert_eq!(
             res.data.attributes.tags[0]
                 .attributes
@@ -340,6 +344,7 @@ mod tests {
                     "status": "ongoing",
                     "year": null,
                     "contentRating": "safe",
+                    "chapterNumbersResetOnNewVolume": true,
                     "tags": [
                         {
                             "id": tag_id,
@@ -453,6 +458,7 @@ mod tests {
                     "status": "ongoing",
                     "year": null,
                     "contentRating": "safe",
+                    "chapterNumbersResetOnNewVolume": true,
                     "tags": [
                         {
                             "id": tag_id,
@@ -567,6 +573,7 @@ mod tests {
                     "status": "ongoing",
                     "year": null,
                     "contentRating": "safe",
+                    "chapterNumbersResetOnNewVolume": true,
                     "tags": [
                         {
                             "id": tag_id,
