@@ -109,6 +109,8 @@ pub struct UpdateManga<'a> {
     #[serde(skip_serializing_if = "Option::is_none")]
     #[builder(default)]
     pub content_rating: Option<ContentRating>,
+    #[builder(default)]
+    pub chapter_numbers_reset_on_new_volume: bool,
     #[serde(skip_serializing_if = "Option::is_none")]
     #[builder(default)]
     pub tags: Option<Vec<Tag>>,
@@ -189,6 +191,7 @@ mod tests {
             "status": null,
             "year": null,
             "contentRating": null,
+            "chapterNumbersResetOnNewVolume": false,
             "tags": null,
             "modNotes": null,
             "version": 2
@@ -214,6 +217,7 @@ mod tests {
                     "status": "completed",
                     "year": 2021,
                     "contentRating": "safe",
+                    "chapterNumbersResetOnNewVolume": true,
                     "tags": [],
                     "state": "published",
                     "version": 2,
@@ -304,6 +308,7 @@ mod tests {
                     "status": "ongoing",
                     "year": null,
                     "contentRating": "safe",
+                    "chapterNumbersResetOnNewVolume": true,
                     "tags": [
                         {
                             "id": tag_id,
@@ -391,6 +396,7 @@ mod tests {
             "publicationDemographic": "shounen",
             "status": "ongoing",
             "contentRating": "safe",
+            "chapterNumbersResetOnNewVolume": false,
             "tags": [tag_id]
         });
         let response_body = json!({
@@ -414,6 +420,7 @@ mod tests {
                     "status": "ongoing",
                     "year": null,
                     "contentRating": "safe",
+                    "chapterNumbersResetOnNewVolume": true,
                     "tags": [
                         {
                             "id": tag_id,
@@ -502,6 +509,7 @@ mod tests {
             "publicationDemographic": "shounen",
             "status": "ongoing",
             "contentRating": "safe",
+            "chapterNumbersResetOneNewVolume": false,
             "tags": [tag_id]
         });
         let response_body = json!({
@@ -525,6 +533,7 @@ mod tests {
                     "status": "ongoing",
                     "year": null,
                     "contentRating": "safe",
+                    "chapterNumbersResetOnNewVolume": true,
                     "tags": [
                         {
                             "id": tag_id,
