@@ -4,9 +4,11 @@
 
 mod create;
 pub(crate) mod list;
+mod list_reports_by_user;
 
 use crate::v5::report::create::CreateReportBuilder;
 use crate::v5::report::list::ListReasonsBuilder;
+use crate::v5::report::list_reports_by_user::ListReportsByUserBuilder;
 use crate::HttpClientRef;
 
 /// Report endpoint handler builder.
@@ -28,6 +30,13 @@ impl ReportBuilder {
         ListReasonsBuilder::default().http_client(self.http_client.clone())
     }
 
+    /// Get a list of reports by the user.
+    ///
+    /// <https://api.mangadex.org/docs.html#operation/get-reports>
+    pub fn list_reports_by_user(&self) -> ListReportsByUserBuilder {
+        ListReportsByUserBuilder::default().http_client(self.http_client.clone())
+    }
+
     /// Create a new report.
     ///
     /// <https://api.mangadex.org/docs.html#operation/post-report>
