@@ -28,6 +28,7 @@ mod upload_session;
 #[cfg(feature = "upload")]
 mod upload_session_file;
 mod user;
+mod user_report;
 mod user_settings;
 
 use std::collections::HashMap;
@@ -67,6 +68,7 @@ pub(crate) use upload_session::UploadSessionResponse;
 #[cfg(feature = "upload")]
 pub(crate) use upload_session_file::{UploadSessionFileAttributes, UploadSessionFileData};
 pub(crate) use user::UserAttributes;
+pub(crate) use user_report::UserReportAttributes;
 pub(crate) use user_settings::UserSettingsAttributes;
 
 pub type AtHomeServerResponse = Result<AtHomeServer>;
@@ -138,6 +140,10 @@ pub type UserData = ApiData<UserObject>;
 pub type UserResponse = Result<UserData>;
 pub type UserListResponse = Result<Results<UserObject>>;
 
+pub type UserReportsObject = ApiObject<UserReportAttributes>;
+pub type UserReportsData = ApiData<UserReportsObject>;
+pub type UserReportsListResponse = Result<Results<UserReportsObject>>;
+
 pub type UserSettingsResponse = Result<UserSettingsAttributes>;
 
 #[derive(Deserialize)]
