@@ -1,6 +1,6 @@
 use serde::Deserialize;
 
-use crate::types::MangaDexDateTime;
+use crate::types::{Language, MangaDexDateTime};
 
 /// General cover information.
 #[derive(Clone, Debug, Deserialize, PartialEq)]
@@ -8,6 +8,7 @@ use crate::types::MangaDexDateTime;
 #[non_exhaustive]
 pub struct CoverAttributes {
     pub description: String,
+    pub locale: Option<Language>,
     /// Volume number in the manga.
     pub volume: Option<String>,
     /// Cover art filename as it's stored on the MangaDex servers.
