@@ -17,7 +17,14 @@ pub struct ScanlationGroupAttributes {
     pub discord: Option<String>,
     pub contact_email: Option<String>,
     pub description: Option<String>,
+    /// <https://twitter.com>
+    ///
+    /// Nullable.
     pub twitter: Option<Url>,
+    /// [https://www.mangaupdates.com/groups.html?id=](https://www.mangaupdates.com)
+    ///
+    /// Nullable.
+    pub manga_updates: Option<Url>,
     /// Languages the scanlation primarily translates or uploads works into.
     pub focused_languages: Option<Vec<Language>>,
     pub locked: bool,
